precision highp float;

uniform sampler2D uTexture;
varying vec2 vTexCoord;
uniform float uAngle;
uniform vec2 uCenter;
uniform vec2 uFill;
uniform float uLevelEnable;
uniform float uLevelHeight;
uniform float uLevelRatio;
const float PI = 3.14159265359;

float getDistance(vec2 fragCoord, vec2 center, float angleCenter) {
    float angleFrag = atan(fragCoord.y - center.y, fragCoord.x - center.x);
    bool canCalculateDistance = false;
    if (angleCenter > 0.0) {
        if (angleFrag > angleCenter || angleFrag < (angleCenter - PI)) {
            canCalculateDistance = true;
        }
    } else {
        if (angleFrag > angleCenter && angleFrag < (angleCenter + PI)) {
            canCalculateDistance = true;
        }
    }
    if(canCalculateDistance) {
        float angleAigu = angleFrag - angleCenter;
        //on divise par 100 pour que ca fonctionne en mediump (range de 2^14=16384) (voir galaxy tab 2)
        //car pour calculer la distance il y a un carré de la diff des x et y (soit une diff de 128 maxi)
        //Par contre ne fonctionne pas pas pour le S3, nous aaovns choisi le s3
        float hypotenuse = distance(center, fragCoord);
        return hypotenuse * sin(angleAigu);
    }
    return -1.0;
}

bool isOverXY(vec2 fragCoord, vec2 center, float angleCenter) {
    float angleFrag = atan(fragCoord.y - center.y, fragCoord.x - center.x);
    if (angleCenter > 0.0) {
        if (angleFrag > angleCenter || angleFrag < (angleCenter - PI)) {
            return true;
        }
    } else {
        if (angleFrag > angleCenter && angleFrag < (angleCenter + PI)) {
            return true;
        }
    }
    return false;
}

void main() {
    vec4 textureColor = texture2D(uTexture, vTexCoord);
    if(uLevelEnable > 0.5) {
        if (!isOverXY(vTexCoord.xy, uFill, uAngle)) {
            float distance = getDistance(vTexCoord.xy, uCenter, uAngle);
            if(distance > 0.0) {
                distance = max(distance, 0.0);
                float ratio = (distance * uLevelRatio) / (uLevelHeight);
                ratio = max(ratio, 0.0);
                ratio = min(ratio, 1.0);
                if(distance < uLevelHeight){
                    textureColor.rgba *= (1.0 - ratio);
                    //textureColor.b = 1.0;
                    //textureColor.a = 1.0;
                } else{
                    textureColor.rgba *= 0.0;
                }
            }
        }
        //Affiche en bleu la zone que l'on traite
        //textureColor.b = 1.0;
        //textureColor.a = 1.0;
    }
    gl_FragColor=textureColor;
}